@@ -16,10 +16,10 @@ public:
         FileNameRole,
         TitleRole,
     };
-    LibraryModel(QObject *parent = nullptr);
+    explicit LibraryModel(QObject *parent = nullptr);
 
     QHash<int, QByteArray> roleNames() const override;
     QVariant data(const QModelIndex &index, int role) const override;
 
     Q_INVOKABLE bool addBook(const QString &fileName);
-};
\ No newline at end of file
+};
